# Code of Conduct

## 1. Our Commitment

We are dedicated to fostering a respectful environment for everyone contributing
to this project. We expect all participants to treat each other with respect,
professionalism, and kindness.

## 2. Expected Behavior

- Be respectful and considerate of others.
- Engage in constructive discussions and offer helpful feedback.
- Gracefully accept constructive criticism.

## 3. Unacceptable Behavior

The following behaviors will not be tolerated:

- Harassment, discrimination, or intimidation of any kind.
- Offensive, abusive, or derogatory language and actions.
- Personal attacks or insults.
- Trolling or disruptive conduct.
- Sharing inappropriate content.

## 4. Reporting Violations

If you experience or witness any behavior that violates this Code of Conduct,
please report it by contacting the project maintainers. All reports will be
reviewed confidentially.

## 5. Enforcement

Violations of this Code of Conduct may result in actions such as warnings,
temporary bans, or permanent exclusion from participation at the discretion of
the maintainers.

## Contact Info

Email: <nsidc@nsidc.org> Organization: National Snow and Ice Data Center¹
Website: <https://nsidc.org/> Date last modified: 01-22-2025

¹Work performed under NASA contract 80GSFC23CA035.
